<?xml version="1.0" ?><!DOCTYPE TS><TS language="lt" version="2.1">
<context>
    <name>AboutDialog</name>
    <message>
        <source> About Boomaga</source>
        <translation>Apie Boomaga</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Apie</translation>
    </message>
    <message>
        <source>Authors</source>
        <translation>Autoriai</translation>
    </message>
    <message>
        <source>Thanks</source>
        <translation>Padėkos</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Vertimai</translation>
    </message>
    <message>
        <source>Version: %1</source>
        <translation>Versija: %1</translation>
    </message>
    <message>
        <source>Boomaga provides a virtual printer for CUPS. This can be used for print preview or for print booklets.</source>
        <translation>Boomaga yra virtualus spausdintuvas skirtas CUPS. Jis gali būti naudojamas spaudinio peržiūrai ar brošiūrų spausdinimui.</translation>
    </message>
    <message>
        <source>Copyright: %1-%2 %3</source>
        <translation>Autorių Teisės: %1-%2 %3</translation>
    </message>
    <message>
        <source>Homepage: %1</source>
        <translation>Tinklalapis: %1</translation>
    </message>
    <message>
        <source>License: %1</source>
        <translation>Licencija: %1</translation>
    </message>
    <message>
        <source>If you are interested in working with our development team, &lt;a %1&gt;join us&lt;/a&gt;.</source>
        <translation>Jeigu jus sudomino darbas su mūsų kūrėjų komanda, &lt;a %1&gt;prisijunkite prie mūsų&lt;/a&gt;.</translation>
    </message>
    <message>
        <source>Special thanks to:</source>
        <translation>Ypatingos padėkos skiriamos:</translation>
    </message>
    <message>
        <source>If you want to help translate, we will be glad to see you in our translation team on &lt;a %1&gt;Transifex server&lt;/a&gt;.</source>
        <translation>Jeigu jūs norėtumėte padėti išversti programą, mums būtų malonu matyti jus mūsų komandoje &lt;a %1&gt;Transifex serveryje&lt;/a&gt;.</translation>
    </message>
    <message>
        <source>Boomaga is developed by the &lt;a %1&gt;Boomaga Team and contributors&lt;/a&gt; on GitHub.</source>
        <translation>Boomaga yra sukurta &lt;a %1&gt;Boomaga komandos ir talkininkų&lt;/a&gt; sistemoje GitHub.</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Nuostatos</translation>
    </message>
    <message>
        <source>Divide your long booklets into smaller sub-booklets for printing.</source>
        <translation>Spausdinimo metu, dalinti ilgą brošiūrą į mažesnes brošiūrėles.</translation>
    </message>
    <message>
        <source>Print as sub-booklets</source>
        <translation>Spausdinti, dalinant į brošiūrėles</translation>
    </message>
    <message>
        <source>Maximum number of sheets in your sub-booklet.</source>
        <translation>Didžiausias lapų skaičius brošiūrėlėje.</translation>
    </message>
    <message>
        <source>Sheets per sub-booklet:</source>
        <translation>Lapų skaičius brošiūrėlėje:</translation>
    </message>
    <message>
        <source>Autosave your jobs every time you print.</source>
        <translation>Automatiškai įrašyti jūsų darbus kas kartą jums spausdinant.</translation>
    </message>
    <message>
        <source>AutoSave the recent sessions</source>
        <translation>Automatiškai įrašyti paskiausius seansus</translation>
    </message>
    <message>
        <source>Allow negative page margins:</source>
        <translation>Leisti neigiamas puslapio paraštes:</translation>
    </message>
    <message>
        <source>Select directory for saved jobs.</source>
        <translation>Pasirinkite katalogą įrašytiems darbams.</translation>
    </message>
    <message>
        <source>Directory for saved sessions:</source>
        <translation>Katalogas, skirtas įrašytiems seansams:</translation>
    </message>
</context>
<context>
    <name>ExportToPdf</name>
    <message>
        <source>Print to PDF</source>
        <translation>Spausdinti kaip PDF</translation>
    </message>
    <message>
        <source>File name</source>
        <translation>Failo pavadinimas</translation>
    </message>
    <message>
        <source>Output file:</source>
        <translation>Išvesties failas:</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>Meta info</source>
        <translation>Meta informacija</translation>
    </message>
    <message>
        <source>Author:</source>
        <translation>Autorius:</translation>
    </message>
    <message>
        <source> The name of the person who created the document.</source>
        <translation>Žmogaus, kuris sukūrė dokumentą, vardas.</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation>Pavadinimas:</translation>
    </message>
    <message>
        <source>Subject:</source>
        <translation>Tema:</translation>
    </message>
    <message>
        <source> The subject of the document.</source>
        <translation>Dokumento tema:</translation>
    </message>
    <message>
        <source> Keywords associated with the document.</source>
        <translation>Raktažodžiai, susiję su dokumentu.</translation>
    </message>
    <message>
        <source>Keywords:</source>
        <translation>Raktažodžiai:</translation>
    </message>
    <message>
        <source>PDF files (*.pdf);;All files (*.*)</source>
        <translation>PDF failai (*.pdf);;Visi failai (*.*)</translation>
    </message>
    <message>
        <source>Overwrite file?</source>
        <translation>Pakeisti failą?</translation>
    </message>
    <message>
        <source>A file named &quot;%1&quot; already exists.
Are you sure you want to overwrite it?</source>
        <translation>Failas pavadinimu &quot;%1&quot; jau yra.
Ar tikrai norite pakeisti šį failą?</translation>
    </message>
    <message>
        <source> The document&apos;s title.</source>
        <translation>Dokumento pavadinimas.</translation>
    </message>
</context>
<context>
    <name>JobListView</name>
    <message>
        <source>%1 pages</source>
        <translation>%1 puslapių</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Failas</translation>
    </message>
    <message>
        <source>&amp;Preferences</source>
        <translation>&amp;Nuostatos</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Pagalba</translation>
    </message>
    <message>
        <source>Layout</source>
        <translation>Išdėstymas</translation>
    </message>
    <message>
        <source>1 up</source>
        <translation>1 puslapis lape</translation>
    </message>
    <message>
        <source>2 up</source>
        <translation>2 puslapiai lape</translation>
    </message>
    <message>
        <source>Booklet</source>
        <translation>Brošiūra</translation>
    </message>
    <message>
        <source>Print on both sides of a sheet.</source>
        <comment>MainForm::Double-sided checkbox tooltip</comment>
        <translation>Spausdinti iš abiejų lapo pusių.</translation>
    </message>
    <message>
        <source>Double-sided</source>
        <comment>MainForm::Double-sided checkbox</comment>
        <translation>Iš abiejų pusių</translation>
    </message>
    <message>
        <source>Jobs</source>
        <translation>Darbai</translation>
    </message>
    <message>
        <source>Printer</source>
        <translation>Spausdintuvas</translation>
    </message>
    <message>
        <source>Configure...</source>
        <translation>Konfigūruoti...</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Įrankių juosta</translation>
    </message>
    <message>
        <source>&amp;Print</source>
        <translation>S&amp;pausdinti</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Išeiti</translation>
    </message>
    <message>
        <source>Print and Close</source>
        <translation>Spausdinti ir užverti</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>Next sheet</source>
        <translation>Kitas lapas</translation>
    </message>
    <message>
        <source>Previous sheet</source>
        <translation>Ankstesnis lapas</translation>
    </message>
    <message>
        <source>About Boomaga</source>
        <translation>Apie Boomaga</translation>
    </message>
    <message>
        <source>Boomaga</source>
        <translation>Boomaga</translation>
    </message>
    <message>
        <source>%v of %m</source>
        <comment>Format for QProgressBar (http://qt-project.org/doc/qt-4.8/qprogressbar.html#format-prop)</comment>
        <translation>%v iš %m</translation>
    </message>
    <message>
        <source>Print the all pages on %1.</source>
        <translation>Spausdinami visi puslapiai ant %1.</translation>
    </message>
    <message>
        <source>Print the odd pages on %1.&lt;p&gt;When finished, turn the pages, insert them into the printer&lt;br&gt;and click the Continue button.</source>
        <translation>Spausdinami nelyginiai puslapiai ant %1.&lt;p&gt;Užbaigus, apverskite puslapius, įdėkite juos į spausdintuvą&lt;br&gt;ir nuspauskite mygtuką Tęsti.</translation>
    </message>
    <message>
        <source>Print the even pages on %1.</source>
        <translation>Spausdinami lyginiai puslapiai ant %1.</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Tęsti</translation>
    </message>
    <message>
        <source>%1 pages</source>
        <comment>Status bar</comment>
        <translation>%1 puslapių</translation>
    </message>
    <message>
        <source>%1 page</source>
        <comment>Status bar</comment>
        <translation>%1 puslapis</translation>
    </message>
    <message>
        <source>%1 sheets</source>
        <comment>Status bar</comment>
        <translation>%1 lapų</translation>
    </message>
    <message>
        <source>%1 sheet</source>
        <comment>Status bar</comment>
        <translation>%1 lapas</translation>
    </message>
    <message>
        <source>Sheet %1 of %2</source>
        <comment>Status bar</comment>
        <translation>Lapai %1 iš %2</translation>
    </message>
    <message>
        <source>Insert blank page after this page</source>
        <translation>Po šio puslapio įterpti tuščią puslapį</translation>
    </message>
    <message>
        <source>Delete this page</source>
        <translation>Ištrinti šį puslapį</translation>
    </message>
    <message>
        <source>Undo delete</source>
        <translation>Atšaukti ištrynimą</translation>
    </message>
    <message>
        <source>Insert blank page before this page</source>
        <translation>Prieš šį puslapį įterpti tuščią puslapį</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Įrašyti</translation>
    </message>
    <message>
        <source>Save project</source>
        <translation>Įrašyti projektą</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>Save as...</source>
        <translation>Įrašyti kaip...</translation>
    </message>
    <message>
        <source>Save project under a new name</source>
        <translation>Įrašyti projektą nauju pavadinimu</translation>
    </message>
    <message>
        <source>Ctrl+Shift+S</source>
        <translation>Ctrl+Shift+S</translation>
    </message>
    <message>
        <source>Open...</source>
        <translation>Atverti...</translation>
    </message>
    <message>
        <source>Open an existing project</source>
        <translation>Atverti egzistuojantį projektą</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Page %1</source>
        <comment>'Undo deletion' menu item</comment>
        <translation>Puslapis %1</translation>
    </message>
    <message>
        <source>Boomaga files (*.boo);;All files (*.*)</source>
        <translation>Boomaga failai (*.boo);;Visi failai (*.*)</translation>
    </message>
    <message>
        <source>Project saved successfully.</source>
        <translation>Projektas sėkmingai įrašytas.</translation>
    </message>
    <message>
        <source>All supported files (*.pdf *.boo);;Boomaga files (*.boo);;PDF files (*.pdf);;All files (*.*)</source>
        <translation>Visi palaikomi failai (*.pdf *.boo);;Boomaga failai (*.boo);;PDF failai (*.pdf);;Visi failai (*.*)</translation>
    </message>
    <message>
        <source>4 up horizontal</source>
        <translation>4 puslapiai lape horizontaliai</translation>
    </message>
    <message>
        <source>4 up vertical</source>
        <translation>4 puslapiai lape vertikaliai</translation>
    </message>
    <message>
        <source>8 up horizontal</source>
        <translation>8 puslapiai lape horizontaliai</translation>
    </message>
    <message>
        <source>8 up vertical</source>
        <translation>8 puslapiai lape vertikaliai</translation>
    </message>
    <message>
        <source>Start new booklet from this page</source>
        <translation>Pradėti naują brošiūrą nuo šio puslapio</translation>
    </message>
    <message>
        <source>Don&apos;t start new booklet from this page</source>
        <translation>Nepradėti naujos brošiūros nuo šio puslapio</translation>
    </message>
    <message>
        <source>Rotate page to the left</source>
        <translation>Pasukti puslapį į kairę</translation>
    </message>
    <message>
        <source>Rotate page to the right</source>
        <translation>Pasukti puslapį į dešinę</translation>
    </message>
    <message>
        <source>Rename job</source>
        <translation>Pervadinti darbą</translation>
    </message>
    <message>
        <source>Rotate job to the left</source>
        <translation>Pasukti darbą į kairę</translation>
    </message>
    <message>
        <source>Rotate job to the right</source>
        <translation>Pasukti darbą į dešinę</translation>
    </message>
    <message>
        <source>Job title:</source>
        <translation>Darbo pavadinimas:</translation>
    </message>
    <message>
        <source>Export the project to PDF</source>
        <translation>Eksportuoti projektą kaip PDF</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Clone job...</source>
        <translation>Dubliuoti darbą...</translation>
    </message>
    <message>
        <source>Clone job</source>
        <translation>Dubliuoti darbą</translation>
    </message>
    <message>
        <source>Number of copies:</source>
        <translation>Kopijų skaičius:</translation>
    </message>
    <message>
        <source>Print with options...</source>
        <translation>Spausdinti su parinktimis...</translation>
    </message>
    <message>
        <source>Select number of copies before printing.</source>
        <translation>Pasirinkti kopijų skaičių prieš spausdinant.</translation>
    </message>
    <message>
        <source>Ctrl+Shift+P</source>
        <translation>Ctrl+Shift+P</translation>
    </message>
    <message>
        <source>Sub-booklets</source>
        <translation>Brošiūrėlės</translation>
    </message>
    <message>
        <source>Undo delete page</source>
        <translation>Atšaukti puslapio ištrynimą</translation>
    </message>
    <message>
        <source>Page %1 of %2</source>
        <comment>Status bar</comment>
        <translation>Puslapis %1 iš %2</translation>
    </message>
    <message>
        <source>Recent files</source>
        <translation>Paskiausiai naudoti failai</translation>
    </message>
    <message>
        <source>&amp;Edit page</source>
        <translation>R&amp;edaguoti puslapį</translation>
    </message>
    <message>
        <source>Edit &amp;job</source>
        <translation>Taisyti &amp;darbą</translation>
    </message>
    <message>
        <source>&amp;Export to PDF...</source>
        <translation>&amp;Eksportuoti į PDF...</translation>
    </message>
    <message>
        <source>Delete pages until the end of the job</source>
        <translation>Ištrinti puslapius iki pat darbo galo</translation>
    </message>
    <message>
        <source>Delete current job</source>
        <translation>Ištrinti esamą darbą</translation>
    </message>
    <message>
        <source>Auto saving</source>
        <translation>Automatinis įrašymas</translation>
    </message>
    <message>
        <source>I can&apos;t create directory &quot;%1&quot;</source>
        <translation>Negaliu sukurti katalogo &quot;%1&quot;</translation>
    </message>
    <message>
        <source>%1 %2: Page %3</source>
        <comment>'Undo deletion' menu item, (%1 - is a job number, %2 - is a job title, %3 - is a page number in this job</comment>
        <translation>%1 %2: Puslapis %3</translation>
    </message>
</context>
<context>
    <name>PdfMerger</name>
    <message>
        <source>I can&apos;t write file &quot;%1&quot;</source>
        <translation>Nepavyksta rašyti failo &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>PrintDialog</name>
    <message>
        <source>Print document</source>
        <translation>Spausdinti dokumentą</translation>
    </message>
    <message>
        <source>Number of copies:</source>
        <translation>Kopijų skaičius:</translation>
    </message>
    <message>
        <source>Collate copies:</source>
        <translation>Surikiuoti kopijas:</translation>
    </message>
</context>
<context>
    <name>PrinterSettings</name>
    <message>
        <source>Margins (mm)</source>
        <translation>Paraštės (mm)</translation>
    </message>
    <message>
        <source>Right:</source>
        <translation>Dešinė:</translation>
    </message>
    <message>
        <source>Bottom:</source>
        <translation>Apačia:</translation>
    </message>
    <message>
        <source>Internal:</source>
        <translation>Vidinė:</translation>
    </message>
    <message>
        <source>Left:</source>
        <translation>Kairė:</translation>
    </message>
    <message>
        <source>Top:</source>
        <translation>Viršus:</translation>
    </message>
    <message>
        <source>Draw border</source>
        <translation>Braižyti rėmelį</translation>
    </message>
    <message>
        <source>Print in reverse order</source>
        <translation>Spausdinti atvirkštine tvarka</translation>
    </message>
    <message>
        <source>Printer has duplexer</source>
        <translation>Spausdintuvas palaiko dvipusį spausdinimą</translation>
    </message>
    <message>
        <source>Manual with reverse (suitable for most printers)</source>
        <translation>Rankinis su apvertimu (tinkamas daugeliui spausdintuvų)</translation>
    </message>
    <message>
        <source>Manual without reverse</source>
        <translation>Rankinis be apvertimo</translation>
    </message>
    <message>
        <source>Preferences of &quot;%1&quot;</source>
        <translation>&quot;%1&quot; nuostatos</translation>
    </message>
    <message>
        <source>Profiles</source>
        <translation>Profiliai</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Reset to default</source>
        <translation>Atstatyti numatytąsias reikšmes</translation>
    </message>
    <message>
        <source>Profile %1</source>
        <comment>Defaul name for created printer profile in the Printer Settings diaog</comment>
        <translation>Profilis %1</translation>
    </message>
    <message>
        <source>Color mode:</source>
        <translation>Spalvos veiksena:</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Numatytasis</translation>
    </message>
    <message>
        <source>Force grayscale</source>
        <translation>Priverstinai pilkio pustoniais</translation>
    </message>
    <message>
        <source>Force color</source>
        <translation>Priverstinai spalvotai</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nustatymai</translation>
    </message>
    <message>
        <source>Print on both sides</source>
        <translation>Spausdinti iš abiejų pusių</translation>
    </message>
    <message>
        <source>Flip on short edge</source>
        <translation>Apversti per trumpąjį kraštą</translation>
    </message>
    <message>
        <source>Flip on long edge</source>
        <translation>Apversti per ilgąjį kraštą</translation>
    </message>
</context>
<context>
    <name>Project</name>
    <message>
        <source>Boomaga</source>
        <comment>Error message title</comment>
        <translation>Boomaga</translation>
    </message>
    <message>
        <source>I can&apos;t write to file &apos;%1&apos;</source>
        <translation>Negaliu įrašyti į failą &apos;%1&apos;</translation>
    </message>
    <message>
        <source>I can&apos;t open file &quot;%1&quot; (No such file or directory)</source>
        <translation>Negaliu atverti failo &quot;%1&quot; (Nėra tokio failo ar katalogo)</translation>
    </message>
    <message>
        <source>I can&apos;t open file &quot;%1&quot; (Access denied)</source>
        <translation>Negaliu atverti failo &quot;%1&quot; (Prieiga negalima)</translation>
    </message>
    <message>
        <source>I can&apos;t open file &quot;%1&quot;</source>
        <translation>Negaliu atverti failo &quot;%1&quot;</translation>
    </message>
    <message>
        <source>I can&apos;t read file &quot;%1&quot; either because it&apos;s not a supported file type, or because the file has been damaged.</source>
        <translation>Negaliu perskaityti failo &quot;%1&quot;, nes arba jis yra nepalaikomo failo tipo, arba jis yra pažeistas.</translation>
    </message>
</context>
<context>
    <name>ProjectFile</name>
    <message>
        <source>I can&apos;t open file &quot;%1&quot;</source>
        <translation>Negaliu atverti failo &quot;%1&quot;</translation>
    </message>
    <message>
        <source>I can&apos;t write to file &apos;%1&apos;</source>
        <translation>Negaliu įrašyti į failą &apos;%1&apos;</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>I can&apos;t read from file &apos;%1&apos;</source>
        <translation>Negaliu perskaityti iš failo &apos;%1&apos;</translation>
    </message>
    <message>
        <source>I can&apos;t write to file &apos;%1&apos;</source>
        <translation>Negaliu įrašyti į failą &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Be pavadinimo</translation>
    </message>
    <message>
        <source>Default</source>
        <comment>Printer profile default name</comment>
        <translation>Numatytasis</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>~/Untitled.pdf</source>
        <translation>~/Bevardis.pdf</translation>
    </message>
</context>
<context>
    <name>SubBookletView</name>
    <message>
        <source>Sub-booklet %1</source>
        <translation>Brošiūrėlė %1</translation>
    </message>
    <message>
        <source>%1 pages</source>
        <translation>%1 puslapių</translation>
    </message>
</context>
<context>
    <name>TmpPdfFile</name>
    <message>
        <source>I can&apos;t create temporary file &quot;%1&quot;</source>
        <translation>Negaliu sukurti laikinojo failo &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Something is wrong. I can't find boomagamerger program.
Please reinstall me.</source>
        <translation>Kažkas blogai. Negaliu rasti programos boomagamerger.
Prašau mane įdiegti iš naujo.</translation>
    </message>
    <message>
        <source>I can&apos;t read file &apos;%1&apos;</source>
        <translation>Negaliu perskaityti failo &apos;%1&apos;</translation>
    </message>
    <message>
        <source>I can&apos;t write to file &apos;%1&apos;</source>
        <translation>Negaliu įrašyti į failą &apos;%1&apos;</translation>
    </message>
</context>
</TS>